Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(77)

Unified Diff: third_party/WebKit/LayoutTests/resources/mojo-helpers.js

Issue 2642873002: Moves mojo.define -> gin.define. (Closed)
Patch Set: rebaseline Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/LayoutTests/resources/mojo-helpers.js
diff --git a/third_party/WebKit/LayoutTests/resources/mojo-helpers.js b/third_party/WebKit/LayoutTests/resources/mojo-helpers.js
index 481ed60b8f1c0a5b7a640668cc992b263e75a7b4..92ddd8d5ae3e7c07dbd8dcf2bdcbf9ab341a1a46 100644
--- a/third_party/WebKit/LayoutTests/resources/mojo-helpers.js
+++ b/third_party/WebKit/LayoutTests/resources/mojo-helpers.js
@@ -12,10 +12,10 @@ let define = (function(){
return function(name, deps, factory) {
let promise = moduleCache.get(name);
if (promise === undefined) {
// This promise must be cached as mojo.define will only call the factory
// function the first time the module is defined.
promise = new Promise(resolve => {
- mojo.define(name, deps, (...modules) => {
+ gin.define(name, deps, (...modules) => {
let result = factory(...modules);
resolve(result);
return result;
@@ -12,10 +12,10 @@ let define = (function(){
let promise = moduleCache.get(name);
if (promise === undefined) {
- // This promise must be cached as mojo.define will only call the factory
+ // This promise must be cached as gin.define will only call the factory
// function the first time the module is defined.
promise = new Promise(resolve => {

Powered by Google App Engine
This is Rietveld 408576698